package com.fastbee.ggroup.service.impl;


import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.domain.GGroups;
import com.fastbee.ggroup.domain.vo.GGroupSiteVo;
import com.fastbee.ggroup.mapper.GGroupsMapper;
import com.fastbee.ggroup.service.IGGroupsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 组Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-09-27
 */
@Service
public class GGroupsServiceImpl implements IGGroupsService
{
    @Autowired
    private GGroupsMapper gGroupsMapper;

    /**
     * 查询组
     * 
     * @param id 组主键
     * @return 组
     */
    @Override
    public GGroups selectGGroupsById(Long id)
    {

        return gGroupsMapper.selectGGroupsById(id);
    }



    /**
     * 查询组列表
     * 
     * @param gGroups 组
     * @return 组
     */
    @Override
    public List<GGroups> selectGGroupsList(GGroups gGroups)
    {

        List<GGroups> groups = gGroupsMapper.selectGGroupsList(gGroups);
        return buildTree(groups);
    }

    @Override
    public List<GGroupSiteVo> selectGGroupsListSites(GGroups gGroups) {
        return gGroupsMapper.selectGGroupsSiteList(gGroups);
    }


    private List<GGroups> buildTree(List<GGroups> groups) {
        Map<Long, GGroups> map = new HashMap<>();
        List<GGroups> roots = new ArrayList<>();

        for (GGroups group : groups) {
            map.put(group.getId(), group);
        }

        for (GGroups group : groups) {
            Long parentId = group.getParentId();
            if (parentId == null || !map.containsKey(parentId)) {
                roots.add(group);
            } else {
                GGroups parent = map.get(parentId);
                if (parent.getChildren() == null) {
                    parent.setChildren(new ArrayList<>());
                }
                parent.getChildren().add(group);
            }
        }

        return roots;
    }




    /**
     * 新增组
     * 
     * @param gGroups 组
     * @return 结果
     */
    @Override
    public int insertGGroups(GGroups gGroups)
    {
        gGroups.setCreateTime(DateUtils.getNowDate());
        return gGroupsMapper.insertGGroups(gGroups);
    }

    /**
     * 修改组
     * 
     * @param gGroups 组
     * @return 结果
     */
    @Override
    public int updateGGroups(GGroups gGroups)
    {
        gGroups.setUpdateTime(DateUtils.getNowDate());
        return gGroupsMapper.updateGGroups(gGroups);
    }

    /**
     * 批量删除组
     * 
     * @param ids 需要删除的组主键
     * @return 结果
     */
    @Override
    public int deleteGGroupsByIds(Long[] ids)
    {
        return gGroupsMapper.deleteGGroupsByIds(ids);
    }

    /**
     * 删除组信息
     * 
     * @param id 组主键
     * @return 结果
     */
    @Override
    public int deleteGGroupsById(Long id)
    {
        return gGroupsMapper.deleteGGroupsById(id);
    }
}
