package com.fastbee.ggroup.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.domain.GLegendType;
import com.fastbee.ggroup.domain.dto.GLegendDto;
import com.github.yulichang.toolkit.JoinWrappers;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.ggroup.mapper.GLegendMapper;
import com.fastbee.ggroup.domain.GLegend;
import com.fastbee.ggroup.service.IGLegendService;

/**
 * 图例Service业务层处理
 *
 * @author kerwincui
 * @date 2024-10-08
 */
@Service
public class GLegendServiceImpl implements IGLegendService
{
    @Autowired
    private GLegendMapper gLegendMapper;

    /**
     * 查询图例
     *
     * @param id 图例主键
     * @return 图例
     */
    @Override
    public GLegend selectGLegendById(Long id)
    {
        return gLegendMapper.selectGLegendById(id);
    }

    /**
     * 查询图例列表
     *
     * @param gLegend 图例
     * @return 图例
     */
    @Override
    public List<GLegendDto> selectGLegendList(GLegend gLegend)
    {

        MPJLambdaWrapper<GLegend> wrapper = new MPJLambdaWrapper<GLegend>()
                .select(GLegend::getId,GLegend::getIcon,GLegend::getType,GLegend::getName)
                .select(GLegendType::getTypeName,GLegendType::getCategory)
                .leftJoin(GLegendType.class,GLegendType::getId,GLegend::getType);

       return gLegendMapper.selectJoinList(GLegendDto.class,wrapper);
//        return gLegendMapper.selectGLegendList(gLegend);
    }

    /**
     * 新增图例
     *
     * @param gLegend 图例
     * @return 结果
     */
    @Override
    public int insertGLegend(GLegend gLegend)
    {
        gLegend.setCreateTime(DateUtils.getNowDate());
        return gLegendMapper.insertGLegend(gLegend);
    }

    /**
     * 修改图例
     *
     * @param gLegend 图例
     * @return 结果
     */
    @Override
    public int updateGLegend(GLegend gLegend)
    {
        gLegend.setUpdateTime(DateUtils.getNowDate());
        return gLegendMapper.updateGLegend(gLegend);
    }

    /**
     * 批量删除图例
     *
     * @param ids 需要删除的图例主键
     * @return 结果
     */
    @Override
    public int deleteGLegendByIds(Long[] ids)
    {
        return gLegendMapper.deleteGLegendByIds(ids);
    }

    /**
     * 删除图例信息
     *
     * @param id 图例主键
     * @return 结果
     */
    @Override
    public int deleteGLegendById(Long id)
    {
        return gLegendMapper.deleteGLegendById(id);
    }
}
